@@ -14,19 +14,16 @@
 
 import fixtures
 import json
-import mock
-from mock import ANY
 import os
+from unittest import mock
+from unittest.mock import ANY
 
 from muranoagent import bunch
-from muranoagent.common import config as cfg
 from muranoagent import exceptions as ex
 from muranoagent.executors import chef
 from muranoagent.tests.unit import base
 from muranoagent.tests.unit import execution_plan as ep
 
-CONF = cfg.CONF
-
 
 class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
     def setUp(self):
@@ -36,7 +33,7 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
     def test_create_nodejson_noatts(self):
         """It tests the manifest without attributes."""
         node = self.chef_executor._create_manifest('cookbook', 'recipe', None)
-        self.assertEqual(node, self.get_nodejs_no_atts())
+        self.assertEqual(json.loads(node), self.get_node_no_atts())
 
     def test_create_nodejson(self):
         """It tests a manifest with attributes."""
@@ -46,10 +43,10 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         }
 
         node = self.chef_executor._create_manifest('cookbook', 'recipe', atts)
-        self.assertEqual(node, self.get_nodejs_atts())
+        self.assertEqual(json.loads(node), self.get_node_atts())
 
     @mock.patch('subprocess.Popen')
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     @mock.patch('os.path.isdir')
     def test_cookbook(self, mock_isdir, mock_exist, open_mock,
@@ -66,12 +63,13 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         mock_subproc_popen.return_value = process_mock
 
         template = self.useFixture(ep.ExPlanDownloable()).execution_plan
+        script = list(template['Scripts'].values())
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script[0]['Options'])
         self.chef_executor.run('test')
 
     @mock.patch('subprocess.Popen')
-    @mock.patch('__builtin__.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     @mock.patch('os.path.isdir')
     def test_cookbook_error(self, mock_isdir, mock_exist, open_mock,
@@ -88,8 +86,9 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         mock_subproc_popen.return_value = process_mock
 
         template = self.useFixture(ep.ExPlanDownloable()).execution_plan
+        script = list(template['Scripts'].values())[0]
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script['Options'])
         self.assertRaises(ex.CustomException, self.chef_executor.run,
                           'test')
 
@@ -102,8 +101,9 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
     def test_chef_no_berkshelf(self):
         """It tests the cookbook path if Berkshelf is not enabled"""
         template = self.useFixture(ep.ExPlanDownloable()).execution_plan
+        script = list(template['Scripts'].values())[0]
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script['Options'])
         cookbook_path = self.chef_executor._create_cookbook_path('cookbook')
         self.assertEqual(cookbook_path, os.path.abspath('path'))
 
@@ -121,8 +121,9 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         mock_subproc_popen.return_value = process_mock
 
         template = self.useFixture(ep.ExPlanBerkshelf()).execution_plan
+        script = list(template['Scripts'].values())[0]
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script['Options'])
         self.chef_executor.module_name = 'test'
         cookbook_path = self.chef_executor._create_cookbook_path('cookbook')
 
@@ -152,8 +153,9 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         mock_subproc_popen.return_value = process_mock
 
         template = self.useFixture(ep.ExPlanCustomBerskfile()).execution_plan
+        script = list(template['Scripts'].values())[0]
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script['Options'])
         self.chef_executor.module_name = 'test'
         cookbook_path = self.chef_executor._create_cookbook_path('cookbook')
 
@@ -183,8 +185,9 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         mock_subproc_popen.return_value = process_mock
 
         template = self.useFixture(ep.ExPlanBerkshelf()).execution_plan
+        script = list(template['Scripts'].values())[0]
         self.chef_executor.load('path',
-                                template['Scripts'].values()[0]['Options'])
+                                script['Options'])
         self.chef_executor.module_name = 'test'
         self.assertRaises(ex.CustomException,
                           self.chef_executor._create_cookbook_path,
@@ -237,8 +240,8 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
             }
         )
 
-    def get_nodejs_atts(self):
-        return json.dumps({
+    def get_node_atts(self):
+        return {
             "run_list": [
                 "recipe[cookbook::recipe]"
             ],
@@ -246,11 +249,11 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
                 "att1": "value1",
                 "att2": "value2"
             }
-        })
+        }
 
-    def get_nodejs_no_atts(self):
-        return json.dumps({
+    def get_node_no_atts(self):
+        return {
             "run_list": [
                 "recipe[cookbook::recipe]"
             ]
-        })
+        }
